/*

 (c) 2002 Brian Kelly under the terms of the GNU GPL
   http://www.gnu.org/copyleft/gpl.html

*/

#include <time.h>
#include <iostream.h>

/*
	bool toInt(char c, int& i)

	PRE: c is an ASCII decimal digit, 0-9
	POST: c is unchanged, i is changed to digit as integer, bool indicates if c was valid

*/
bool toInt( char c, int& i );

void dateOut( ostream &out );

